summaryrefslogtreecommitdiffstats
path: root/kinit/start_kdeinit.c
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:31:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:31:13 -0600
commit0ae5679aa160245af248836e1d7743aeff63f2e1 (patch)
tree64608dccc9bfd57800995a414f6287b7605ca637 /kinit/start_kdeinit.c
parentd3b5575f31f14629dbd3fd900665e1a69aa7bcd5 (diff)
downloadtdelibs-0ae5679aa160245af248836e1d7743aeff63f2e1.tar.gz
tdelibs-0ae5679aa160245af248836e1d7743aeff63f2e1.zip
Additional kde to tde renaming
Diffstat (limited to 'kinit/start_kdeinit.c')
-rw-r--r--kinit/start_kdeinit.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kinit/start_kdeinit.c b/kinit/start_kdeinit.c
index a86b366e5..9d2626057 100644
--- a/kinit/start_kdeinit.c
+++ b/kinit/start_kdeinit.c
@@ -32,9 +32,9 @@
/*
Prevent getting killed by bad heuristic in Linux OOM-killer.
This wrapper decreases the chance OOM killer kills it (or its children,
- namely kdeinit), opens a pipe and forks. Child drops privileges
- and launches kdeinit. Since processes started by kdeinit should
- not have this protection, kdeinit will after forking send the new
+ namely tdeinit), opens a pipe and forks. Child drops privileges
+ and launches tdeinit. Since processes started by tdeinit should
+ not have this protection, tdeinit will after forking send the new
PID using the pipe and wait for a signal. This parent will reset the protection
and SIGUSR1 the process to continue.
returns 1 if pid is valid
@@ -113,7 +113,7 @@ int main(int argc, char **argv)
return 1;
}
close( pipes[ 0 ] );
/* read original environment passed by start_kdeinit_wrapper */
if( read( 0, header, 7 ) == 7 && strncmp( header, "environ", 7 ) == 0 ) {
unsigned count;
if( read( 0, &count, sizeof( unsigned )) == sizeof( unsigned )
@@ -113,7 +113,7 @@ int main(int argc, char **argv)
}
close( pipes[ 0 ] );
- /* read original environment passed by start_kdeinit_wrapper */
+ /* read original environment passed by start_tdeinit_wrapper */
if( read( 0, header, 7 ) == 7 && strncmp( header, "environ", 7 ) == 0 ) {
unsigned count;